@@ -1,37 +1,11 @@
 package CHI::Test::Class;
-use CHI::Util qw(dump_one_line require_dynamic);
+use CHI::Util qw(require_dynamic);
 use Getopt::Long;
-use Module::Find qw(findallmod);
 use Module::Load::Conditional qw(can_load);
-use Test::More qw();
 use strict;
 use warnings;
 use base qw(Test::Class);
 
-sub load_tests {
-    my ($class) = @_;
-
-    my $test_class_pattern;
-    if ( defined( $test_class_pattern = $ENV{TEST_CLASS} ) ) {
-        $test_class_pattern =~ s{/}{::}g;
-    }
-    my @classes;
-    my @candidates = findallmod('CHI::t');
-
-    foreach my $class (@candidates) {
-        next
-          if defined($test_class_pattern) && $class !~ /$test_class_pattern/o;
-        require_dynamic($class);
-    }
-    if ( $ENV{TEST_STACK_TRACE} ) {
-
-        # Show entire stack trace when testing aborts with fatal error
-        $SIG{'__DIE__'}  = sub { Carp::confess(@_) };
-        $SIG{'__WARN__'} = sub { Carp::confess(@_) };
-    }
-    return @classes;
-}
-
 sub runtests {
     my ($class) = @_;
 
@@ -40,20 +14,26 @@ sub runtests {
     GetOptions( 'm|method=s' => sub { $ENV{TEST_METHOD} = ".*" . $_[1] . ".*" },
     );
 
+    if ( $ENV{TEST_STACK_TRACE} ) {
+
+        # Show entire stack trace on fatal errors or warnings
+        $SIG{'__DIE__'}  = sub { Carp::confess(@_) };
+        $SIG{'__WARN__'} = sub { Carp::confess(@_) };
+    }
+
     # Check for internal_only
     #
     if ( $class->internal_only && !$class->is_internal ) {
-        $class->skip_all('internal test only');
+        $class->SKIP_ALL('internal test only');
     }
 
     # Check for required modules
     #
     if ( my $required_modules = $class->required_modules ) {
-        unless ( can_load( modules => $required_modules ) ) {
-            $class->skip_all(
-                sprintf( 'one of required modules not installed: %s',
-                    dump_one_line($required_modules) )
-            );
+        while ( my ( $key, $value ) = each(%$required_modules) ) {
+            unless ( can_load( modules => { $key, $value } ) ) {
+                $class->SKIP_ALL("one of required modules not installed: $key");
+            }
         }
     }
 
@@ -63,12 +43,6 @@ sub runtests {
     Test::Class::runtests($test_obj);
 }
 
-sub skip_all {
-    my ( $class, $reason ) = @_;
-
-    Test::More::plan( skip_all => $reason );
-}
-
 sub is_internal {
     return $ENV{CHI_INTERNAL_TESTS};
 }
